@@ -733,7 +733,7 @@ class fit_files(object):
             warnings.simplefilter("ignore")
             self.bfit.fetch_files.draw_all(figstyle='fit',ignore_check=False)
         
-        if len(self.fit_lines.keys())>8:
+        if len(self.fit_lines.keys())>self.bfit.legend_max_draw:
             self.plt.gca('fit').get_legend().remove()
             self.plt.tight_layout('fit')
         
@@ -1066,14 +1066,11 @@ class fit_files(object):
         if label:   
             draw_id = label
         else:
-            
-            draw_id = 'Set 0'
+            draw_id = ''
             
             if self.bfit.draw_style.get() == 'stack':
                 ax = self.plt.gca(figstyle)
-                if hasattr(ax,'draw_objs'):
-                    draw_id = 'Set %d' % len(ax.draw_objs.keys())    
-            
+                
         # make new window
         style = self.bfit.draw_style.get()
         if style == 'new' or not self.plt.active[figstyle]:
@@ -1119,7 +1116,9 @@ class fit_files(object):
         self.plt.xlabel(figstyle,xdraw)
         self.plt.ylabel(figstyle,ydraw)
         self.plt.tight_layout(figstyle)
-        self.plt.legend(figstyle,fontsize='x-small')
+        
+        if draw_id:
+            self.plt.legend(figstyle,fontsize='x-small')
         
         # bring window to front
         raise_window()
@@ -1937,12 +1936,13 @@ class fitline(object):
                 
                 if force_modify:
                     entry.delete(0,'end')
-                
+                    self.parentry[p]['fixed'][0].set(fitdat.fitpar['fixed'][p])
+                    
                 if not entry.get():
                     entry.insert(0,str(fitdat.fitpar[col][p]))
                 
                 entry.grid(column=c,row=r,padx=5,sticky=E); c += 1
-            self.parentry[p]['fixed'][0].set(fitdat.fitpar['fixed'][p])
+            
         r = min_n_par+1
         
         self.disable_entry_callback = False
@@ -1957,7 +1957,6 @@ class fitline(object):
             
             for col in ('p0','blo','bhi'):
                 c += 1
-                
                 value = StringVar()
                 entry = ttk.Entry(fitframe,textvariable=value,width=13)
                 entry.insert(0,str(fitdat.fitpar[col][p]))
@@ -2128,7 +2127,6 @@ class fitline(object):
         values = None
         res = self.bfit.data[run].fitpar['res']
         isfitted = any([res[k] for k in res]) # is this run fitted?
-        fixed = None
         
         if fit_files.set_prior_p0.get() and not isfitted:
             r = 0
@@ -2141,9 +2139,9 @@ class fitline(object):
                     r = data.run
                     values = {k:(res[k],
                                  data.fitpar['blo'][k],
-                                 data.fitpar['bhi'][k]) for k in res}
+                                 data.fitpar['bhi'][k],
+                                 data.fitpar['fixed'][k]) for k in res}
                     parentry = self.bfit.fit_files.fit_lines[rkey].parentry
-                    fixed = {k:parentry[k]['fixed'][0].get() for k in res}
                     
         # get calcuated initial values
         if values is None:
@@ -2152,9 +2150,6 @@ class fitline(object):
             
         # set to data
         self.bfit.data[run].set_fitpar(values)
-        if fixed is not None and self.parentry:
-            for k in fixed.keys():
-                self.parentry[k]['fixed'][0].set(fixed[k])
             
         return tuple(plist)
         
